
.. _Aergo: http://github.com/aergoio/aergo
.. _HeraPy: http://github.com/aergoio/herapy


.. _what_is_herapy:

What is Herapy?
===============

HeraPy_ is the Aergo_ SDK (Hera) library for Python3 provides to

* connect to a Aergo_ blockchain node
* create a new account
* manage an account
* create a transaction
* sign a transaction
* send a transaction
* deploy a smart contract
* call a smart contract
* query a smart contract
* and so on.


